@@ -5,8 +5,9 @@ from enum import Enum
 from typing import Union
 
 
-from ..abs_class import ThemedWidget
+from ..abs_class import ThemedWindow
 from ..font import build_all_font
+from ..color import add_tk_instance
 
 
 class Theme(Enum):
@@ -15,22 +16,21 @@ class Theme(Enum):
     LIGHT = "light"
 
 
-class Tk(tk.Tk, ThemedWidget):
+class Tk(tk.Tk, ThemedWindow):
     def __init__(self):
         tk.Tk.__init__(self)
+        ThemedWindow.__init__(self)
         self.__theme = None
-        self.__theme_updated_id = None
         self.__theme_forced = Theme.AUTO
-        self.bind('<Configure>', self.on_configure)
-        self.after(50, self.update_theme)
         build_all_font(self)
+        add_tk_instance(self)
 
     @property
     def theme(self):
         if self.__theme_forced != Theme.AUTO:
             return self.__theme_forced
         elif self.__theme is None:
-            self.__theme = darkdetect.theme()
+            self.__theme = darkdetect.theme().lower()
         return self.__theme
 
     @theme.setter
@@ -43,16 +43,8 @@ class Tk(tk.Tk, ThemedWidget):
             raise RuntimeError("Wrong theme")
 
     def on_configure(self, event):
-        if event.widget == self and self.__theme_forced == Theme.AUTO:
+        if self.__theme_forced == Theme.AUTO:
             if self.theme != darkdetect.theme():
                 self.__theme = None
-                if self.__theme_updated_id is not None:
-                    self.after_cancel(self.__theme_updated_id)
-                self.__theme_updated_id = self.after(500, self.update_theme)
+                ThemedWindow.on_configure(self, event)
 
-    def update_theme(self):
-        self.config(bg=self.get_color('main_bg'))
-        self.configure(background=self.get_color('main_bg'))
-        for child in self.children.values():
-            if isinstance(child, ThemedWidget):
-                child.update_theme()
